log_format {{ namespace }} '$remote_addr - $remote_user [$time_local] "$request"'
                    '$status $body_bytes_sent "$http_referer" "$http_user_agent"'
                    '"$http_x_forwarded_for" "$api_name"';

{% for map in maps %}{{ map }}
{% endfor %}

{% for upstream in upstreams %}{{ upstream }}
{% endfor %}

{% for server in servers %}{{ server }}
{% endfor %}

